Module: DpnSwaggerEngine

Defined in:
lib/dpn_swagger_engine.rb,
lib/dpn_swagger_engine/engine.rb,
lib/dpn_swagger_engine/version.rb,
app/helpers/dpn_swagger_engine/swagger_helper.rb,
app/helpers/dpn_swagger_engine/application_helper.rb,
app/controllers/dpn_swagger_engine/swaggers_controller.rb,
app/controllers/dpn_swagger_engine/application_controller.rb

Overview

Mount swagger-ui as a rails engine to document and explore the DPN REST API within the dpn-server project.

Defined Under Namespace

Modules: ApplicationHelper, SwaggerHelper Classes: ApplicationController, Configuration, Engine, SwaggersController

Constant Summary collapse

VERSION =

Version digits match swagger-ui version, with the last digit representing bug fixes or additions for this gem.

'2.2.3.5'.freeze

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.configurationObject



46
47
48
# File 'lib/dpn_swagger_engine/engine.rb', line 46

def configuration
  @configuration ||= Configuration.new
end

Class Method Details

.configure {|configuration| ... } ⇒ Object

Yields:



50
51
52
# File 'lib/dpn_swagger_engine/engine.rb', line 50

def configure
  yield(configuration)
end